package com.sugamobile.realwear_voice_command

import android.app.Activity
import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.view.View
import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

class RealwearVoiceCommandPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    companion object {
        private const val INTENT_ACTION_SPEECH_EVENT =
            "com.realwear.wearhf.intent.action.SPEECH_EVENT"

        private const val RECEIVING_EVENT_SET_COMMANDS = "set_commands"

        private const val SENDING_EVENT_COMMAND_RECEIVED = "command_received_event"
    }

    private lateinit var channel: MethodChannel

    private var activity: Activity? = null

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "realwear_voice_command")
        channel.setMethodCallHandler(this)
        flutterPluginBinding.applicationContext
            .registerReceiver(asrBroadcastReceiver, IntentFilter(INTENT_ACTION_SPEECH_EVENT))
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivity() {
        activity = null
    }

    override fun onDetachedFromActivityForConfigChanges() {
        activity = null
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            RECEIVING_EVENT_SET_COMMANDS -> {
                val commands = call.argument<String>("commands")!!
                setCommands(commands)
                result.success(null)
            }
            else -> result.notImplemented()
        }
    }

    private fun setCommands(commands: String) {
        activity?.findViewById<View>(android.R.id.content)?.contentDescription =
            "hf_add_commands:${commands}"
    }

    private val asrBroadcastReceiver: BroadcastReceiver = object : BroadcastReceiver() {
        override fun onReceive(context: Context, intent: Intent) {
            when (intent.action) {
                INTENT_ACTION_SPEECH_EVENT -> {
                    val command = intent.getStringExtra("command")
                    channel.invokeMethod(
                        SENDING_EVENT_COMMAND_RECEIVED,
                        hashMapOf("command" to command)
                    )
                }
            }
        }
    }
}
