import 'package:event_bus/event_bus.dart';
import 'package:flutter/services.dart';
import 'package:logger/logger.dart';
import 'package:realwear_voice_command/core/injector.dart';
import 'package:realwear_voice_command/core/voice_command_manager.dart';
import 'package:realwear_voice_command/events/voice_command_received_event.dart';
import 'package:realwear_voice_command/models/voice_command.dart';
import 'package:suga_core/suga_core.dart';

class MethodChannelHandler {
  static const String _receivingEventCommandReceived = 'command_received_event';

  static const String _sendingEventSetCommands = 'set_commands';

  final _methodChannel = const MethodChannel('realwear_voice_command');

  final EventBus _eventBus;
  final Logger _logger;

  MethodChannelHandler(this._eventBus, this._logger);

  void setup() {
    _methodChannel.setMethodCallHandler(
      (call) {
        _logger.d("MethodCall: $call");
        switch (call.method) {
          case _receivingEventCommandReceived:
            final arguments = Map<String, String?>.from(call.arguments as Map);
            final value = arguments['command']!;
            final commands = realwearVoiceCommandInjector<VoiceCommandManager>().fromValue(value);
            for (final command in commands) {
              _eventBus.fire(VoiceCommandReceivedEvent(command));
            }
            break;
        }
        return Future.value();
      },
    );
  }

  Future<Unit> setCommands(Set<VoiceCommand> commands) async {
    _logger.d("VoiceCommands: $commands");
    final values = commands.map((e) => e.value).toSet().join('|');
    await _methodChannel.invokeMethod(_sendingEventSetCommands, {"commands": values});
    return unit;
  }
}
