import 'package:draggable_widget/draggable_widget.dart';
import 'package:flutter/material.dart';
import 'package:realwear_voice_command/core/injector.dart';
import 'package:realwear_voice_command/realwear_voice_command.dart';
import 'package:realwear_voice_command/widgets/draggable/voice_draggable_widget_model.dart';
import 'package:realwear_voice_command/widgets/draggable/widgets/input_command_dialog.dart';
import 'package:suga_core/suga_core.dart';

class VoiceDraggableWidget extends StatefulWidget {
  final Widget child;
  final double topMargin;
  final double bottomMargin;
  final double horizontalSpace;

  const VoiceDraggableWidget({
    Key? key,
    required this.child,
    this.topMargin = 80,
    this.bottomMargin = 20,
    this.horizontalSpace = 20,
  }) : super(key: key);

  @override
  _VoiceDraggableWidgetState createState() => _VoiceDraggableWidgetState();
}

class _VoiceDraggableWidgetState extends BaseViewState<VoiceDraggableWidget, VoiceDraggableWidgetModel> {
  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        widget.child,
        if (RealwearVoiceCommand.debugMode)
          DraggableWidget(
            bottomMargin: widget.bottomMargin,
            topMargin: widget.topMargin,
            horizontalSpace: widget.horizontalSpace,
            shadowBorderRadius: 1,
            normalShadow: const BoxShadow(color: Colors.transparent),
            initialPosition: AnchoringPosition.topLeft,
            child: FloatingActionButton(
              onPressed: () => viewModel.onClick(),
              child: const Icon(Icons.code_outlined),
            ),
          ),
        if (RealwearVoiceCommand.debugMode)
          StreamBuilder<bool>(
            stream: viewModel.statusShowDialog,
            builder: (context, snapshot) {
              if (snapshot.hasData) {
                if (snapshot.data!) {
                  return Positioned(
                    top: 0,
                    right: 0,
                    bottom: 0,
                    left: 0,
                    child: InputCommandDialog(
                      onConfirm: (String command) => viewModel.onCommandReceived(command.toUpperCase()),
                      onCancel: viewModel.onCancel,
                      commandTextEditor: viewModel.commandTextEditor,
                      focusNode: viewModel.focusNode,
                    ),
                  );
                }
              }
              return Container();
            },
          ),
      ],
    );
  }

  @override
  VoiceDraggableWidgetModel createViewModel() => realwearVoiceCommandInjector<VoiceDraggableWidgetModel>();
}
