import 'dart:async';

import 'package:event_bus/event_bus.dart';
import 'package:flutter/cupertino.dart';
import 'package:realwear_voice_command/core/voice_command_manager.dart';
import 'package:realwear_voice_command/events/voice_command_received_event.dart';
import 'package:suga_core/suga_core.dart';

class VoiceDraggableWidgetModel extends BaseViewModel {
  final VoiceCommandManager _voiceCommandManager;
  final EventBus _eventBus;
  final _controller = StreamController<bool>();
  final commandTextEditor = TextEditingController();
  final focusNode = FocusNode();

  Stream<bool> get statusShowDialog => _controller.stream;

  VoiceDraggableWidgetModel(
    this._voiceCommandManager,
    this._eventBus,
  );

  void onCommandReceived(String inputCommand) {
    _controller.sink.add(false);
    commandTextEditor.clear();

    final commands = _voiceCommandManager.fromValue(inputCommand);
    for (final command in commands) {
      _eventBus.fire(VoiceCommandReceivedEvent(command));
    }
  }

  void _openKeyboard() {
    focusNode.requestFocus();
  }

  void onCancel() {
    commandTextEditor.clear();
    _controller.sink.add(false);
  }

  void onClick() {
    _controller.sink.add(true);
    _openKeyboard();
  }

  @override
  void disposeState() {
    _controller.close();
    super.disposeState();
  }
}
