import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class InputCommandDialog extends StatelessWidget {
  final Function(String) onConfirm;
  final Function() onCancel;
  final double width;
  final double height;
  final TextEditingController commandTextEditor;
  final FocusNode focusNode;

  const InputCommandDialog({
    Key? key,
    required this.onConfirm,
    this.width = 350,
    this.height = 250,
    required this.onCancel,
    required this.commandTextEditor,
    required this.focusNode,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Dialog(
      insetPadding: EdgeInsets.zero,
      child: Container(
        width: width,
        height: height,
        padding: const EdgeInsets.all(10),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            const Text(
              "Input Command",
              style: TextStyle(
                color: Colors.blue,
                fontWeight: FontWeight.w600,
                fontSize: 24,
              ),
            ),
            TextField(
              controller: commandTextEditor,
              decoration: InputDecoration(
                labelText: "Command",
                border: OutlineInputBorder(borderRadius: BorderRadius.circular(10)),
                enabledBorder: OutlineInputBorder(borderRadius: BorderRadius.circular(10)),
                focusedBorder: OutlineInputBorder(borderRadius: BorderRadius.circular(10)),
              ),
              autofocus: true,
              focusNode: focusNode,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: [
                GestureDetector(
                  onTap: () => onCancel(),
                  child: Container(
                    width: 100,
                    height: 50,
                    decoration: BoxDecoration(borderRadius: BorderRadius.circular(10), color: const Color(0xFF0A65B6)),
                    child: const Center(
                      child: Text(
                        "Cancel",
                        style: TextStyle(
                          fontSize: 18,
                          fontWeight: FontWeight.bold,
                          color: Colors.white,
                        ),
                        textAlign: TextAlign.center,
                      ),
                    ),
                  ),
                ),
                GestureDetector(
                  onTap: () => onConfirm(commandTextEditor.text),
                  child: Container(
                    width: 100,
                    height: 50,
                    decoration: BoxDecoration(borderRadius: BorderRadius.circular(10), color: const Color(0xFF0A65B6)),
                    child: const Center(
                      child: Text(
                        "Confirm",
                        style: TextStyle(
                          fontSize: 18,
                          fontWeight: FontWeight.bold,
                          color: Colors.white,
                        ),
                        textAlign: TextAlign.center,
                      ),
                    ),
                  ),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}
