import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:realwear_voice_command/core/injector.dart';
import 'package:realwear_voice_command/models/voice_command.dart';
import 'package:realwear_voice_command/widgets/voice_command_widget_model.dart';
import 'package:suga_core/suga_core.dart';
import 'package:visibility_detector/visibility_detector.dart';

class VoiceCommandWidget extends StatefulWidget {
  final Widget child;
  final Set<VoiceCommand> commands;
  final Function(VoiceCommand) onCommandReceived;

  const VoiceCommandWidget({
    Key? key,
    required this.child,
    required this.commands,
    required this.onCommandReceived,
  }) : super(key: key);

  @override
  _VoiceCommandWidgetState createState() => _VoiceCommandWidgetState();
}

class _VoiceCommandWidgetState extends BaseViewState<VoiceCommandWidget, VoiceCommandWidgetModel> {
  @override
  VoiceCommandWidgetModel createViewModel() => realwearVoiceCommandInjector<VoiceCommandWidgetModel>();

  @override
  void loadArguments() {
    viewModel.commands = widget.commands;
    viewModel.onCommandReceived = widget.onCommandReceived;
    super.loadArguments();
  }

  @override
  Widget build(BuildContext context) {
    return VisibilityDetector(
      key: UniqueKey(),
      onVisibilityChanged: viewModel.onVisibilityChanged,
      child: widget.child,
    );
  }
}
